@@ -175,6 +175,7 @@ create_release_row (const char *version,
       gtk_widget_set_margin_top (GTK_WIDGET (fallback_label), 5);
       gtk_widget_add_css_class (GTK_WIDGET (fallback_label), "dim-label");
       gtk_label_set_xalign (fallback_label, 0.0);
+      gtk_label_set_wrap (fallback_label, TRUE);
       gtk_box_append (content_box, GTK_WIDGET (fallback_label));
     }
 
@@ -388,6 +389,20 @@ bz_releases_list_set_property (GObject      *object,
     }
 }
 
+static gboolean
+invert_boolean (gpointer object,
+                gboolean value)
+{
+  return !value;
+}
+
+static gboolean
+is_null (gpointer object,
+         GObject *value)
+{
+  return value == NULL;
+}
+
 static void
 bz_releases_list_class_init (BzReleasesListClass *klass)
 {
@@ -415,6 +430,8 @@ bz_releases_list_class_init (BzReleasesListClass *klass)
   gtk_widget_class_bind_template_child (widget_class, BzReleasesList, preview_box);
   gtk_widget_class_bind_template_child (widget_class, BzReleasesList, show_all_box);
   gtk_widget_class_bind_template_callback (widget_class, show_all_releases_cb);
+  gtk_widget_class_bind_template_callback (widget_class, is_null);
+  gtk_widget_class_bind_template_callback (widget_class, invert_boolean);
 }
 
 static void
